Get Configuration Object
/pdc/config
Request
-
includeReferences: boolean
Indicates whether to include references objects.
-
name: string
The configuration object's name.
-
type: string
The configuration object's type.
Valid pricing configuration objects: ZONE_RESULT_CONFIGURATION, VALUE_MAP, STANDARD_ZONE_MODEL, GEO_ZONE_MODEL, BALANCE_ELEMENT, RUM_CONFIGURATION, HOLIDAY_CALENDAR, ATTRIBUTE_SPEC_MAP, BUSINESS_PROFILE, ITEM_TYPE_SELECTOR, CUSTOM_ANALYZER_RULE, POLICY_SPECIFICATION, DYNAMIC_QUOTA_SELECTOR, POLICY_LABEL, DELIVERABLE, PSCTEMPLATE, TAX_CODE, TAX_EXEMPTION_CODE, or PRICE_TAG_CONFIG.
There's no request body for this operation.
Back to TopResponse
- application/json
200 Response
object-
attributeSpecMaps: array
attributeSpecMaps
-
balanceElements: array
balanceElements
-
businessProfiles: array
businessProfiles
-
customAnalyzerRules: array
customAnalyzerRules
-
deliverables: array
deliverables
-
dynamicQuotaSelectors: array
dynamicQuotaSelectors
-
geoZoneModel: array
geoZoneModel
-
holidayCalendar: array
holidayCalendar
-
itemTypeSelectors: array
itemTypeSelectors
-
policyLabels: array
policyLabels
-
policySpecifications: array
policySpecifications
-
priceTagConfigs: array
priceTagConfigs
-
productSpecCharacteristicTemplates: array
productSpecCharacteristicTemplates
-
rumConfigurations: array
rumConfigurations
-
standardZoneModel: array
standardZoneModel
-
taxCodes: array
taxCodes
-
taxExemptionCodes: array
taxExemptionCodes
-
valueMap: array
valueMap
-
zoneResultConfiguration: array
zoneResultConfiguration
object-
leftOperand: object
ARumExpressionJXB
-
operation: string
Allowed Values:
[ "ADD", "DIVIDE", "MULTIPLY", "SUBTRACT" ] -
rightOperand: object
ARumExpressionJXB
object-
code: string
-
consumptionRule: string
Allowed Values:
[ "EARLIEST_EXPIRATION", "EARLIEST_EXPIRATION_EARLIEST_START", "EARLIEST_EXPIRATION_LATEST_START", "EARLIEST_START", "EARLIEST_START_EARLIEST_EXPIRATION", "EARLIEST_START_LATEST_EXPIRATION", "LATEST_EXPIRATION", "LATEST_EXPIRATION_EARLIEST_START", "LATEST_EXPIRATION_LATEST_START", "LATEST_START", "LATEST_START_EARLIEST_EXPIRATION", "LATEST_START_LATEST_EXPIRATION", "NONE" ]Specify the order in which sub-balances of a balance element are consumed. -
counter: boolean
-
description: string
-
expiryNotification: boolean
-
externalID: string
-
foldable: boolean
-
internalId: string
-
name: string
-
newName: string
-
numericCode: integer
(int64)
-
obsolete: boolean
-
priceListName: string
-
roundingRules: array
roundingRules
-
symbol: string
-
transientElement: boolean
object-
applyToChildEvents: boolean
-
eventName: string
-
precision: integer
-
processingStage: string
Allowed Values:
[ "ALTERATION", "AR", "CHARGING", "TAXATION" ] -
roundingMode: string
Allowed Values:
[ "DOWN", "DOWN_ALT", "EVEN", "FLOOR", "FLOOR_ALT", "NEAREST", "UP" ]Specifies how a RUM quantity is rounded. -
toleranceMax: number
(double)
-
toleranceMin: number
(double)
-
tolerancePercentage: number
(double)
object-
leftOperand: object
CustomRuleExpressionJXB
-
operator: string
Allowed Values:
[ "AND", "EQUAL_TO", "GREATER_THAN", "GREATER_THAN_EQUAL", "INTERSECT", "IN_LIST", "LESS_THAN", "LESS_THAN_EQUAL", "NOT", "NOT_EQUAL_TO", "OR", "REGEX" ] -
rightOperand: object
CustomRuleExpressionJXB
-
seperator: string
object-
lhsFieldIdentifier: object
FieldIdentifierJXB
-
operator: string
Allowed Values:
[ "AND", "EQUAL_TO", "GREATER_THAN", "GREATER_THAN_EQUAL", "INTERSECT", "IN_LIST", "LESS_THAN", "LESS_THAN_EQUAL", "NOT", "NOT_EQUAL_TO", "OR", "REGEX" ] -
rhsFieldIdentifier: object
FieldIdentifierJXB
-
seperator: string
object-
lhsFieldKind: string
Allowed Values:
[ "CUSTOMER_SPEC_FIELD", "EVENT_SPEC_FIELD", "PRODUCT_SPEC_FIELD", "PROFILE_SPEC_FIELD" ] -
lhsFieldName: string
-
operator: string
Allowed Values:
[ "AND", "EQUAL_TO", "GREATER_THAN", "GREATER_THAN_EQUAL", "INTERSECT", "IN_LIST", "LESS_THAN", "LESS_THAN_EQUAL", "NOT", "NOT_EQUAL_TO", "OR", "REGEX" ] -
rhsFieldKind: string
Allowed Values:
[ "CUSTOMER_SPEC_FIELD", "EVENT_SPEC_FIELD", "PRODUCT_SPEC_FIELD", "PROFILE_SPEC_FIELD" ] -
rhsFieldName: string
-
seperator: string
object-
fieldKind: string
Allowed Values:
[ "CUSTOMER_SPEC_FIELD", "EVENT_SPEC_FIELD", "PRODUCT_SPEC_FIELD", "PROFILE_SPEC_FIELD" ] -
fieldName: string
-
fieldValue: string
-
operator: string
Allowed Values:
[ "AND", "EQUAL_TO", "GREATER_THAN", "GREATER_THAN_EQUAL", "INTERSECT", "IN_LIST", "LESS_THAN", "LESS_THAN_EQUAL", "NOT", "NOT_EQUAL_TO", "OR", "REGEX" ] -
seperator: string
object-
fieldSelector: object
FieldSelectorJXB
-
qualifier: string
Allowed Values:
[ "ORIGINATING", "TERMINATING" ]
object-
conditionFieldKind: string
Allowed Values:
[ "CUSTOMER_SPEC_FIELD", "EVENT_SPEC_FIELD", "PRODUCT_SPEC_FIELD", "PROFILE_SPEC_FIELD" ] -
conditionFieldName: string
-
operator: string
Allowed Values:
[ "AND", "EQUAL_TO", "GREATER_THAN", "GREATER_THAN_EQUAL", "INTERSECT", "IN_LIST", "LESS_THAN", "LESS_THAN_EQUAL", "NOT", "NOT_EQUAL_TO", "OR", "REGEX" ] -
selectorFieldKind: string
Allowed Values:
[ "CUSTOMER_SPEC_FIELD", "EVENT_SPEC_FIELD", "PRODUCT_SPEC_FIELD", "PROFILE_SPEC_FIELD" ] -
selectorFieldName: string
object-
deliverableType: string
Allowed Values:
[ "PRODUCT", "SERVICE" ] -
description: string
-
entitlement: object
EntitlementJXB
-
externalID: string
-
internalId: string
-
name: string
-
newName: string
-
obsolete: boolean
-
permittedName: string
-
permittedType: string
Allowed Values:
[ "CUSTOMER", "PRODUCT" ] -
priceListName: string
-
productType: string
Allowed Values:
[ "ADMINISTRATIVE", "PHYSICAL_GOODS" ] -
revenueBasisItem: object
RevenueBasisItemJXB
-
revenueGlid: string
object-
allowanceValidityMode: string
Allowed Values:
[ "ALWAYS", "CURRENT_BILLING", "CURRENT_RECURRING", "MULTIPLE_BILLING", "MULTIPLE_RECURRING", "NEXT_BILLING" ] -
allowanceValidityPeriod: integer
-
allowanceValue: number
(double)
-
description: string
-
entitlementType: string
Allowed Values:
[ "ALLOWANCE_ONE_TIME", "ALLOWANCE_RECURRING", "FEATURE" ] -
featureValue: string
-
name: string
-
resourceBalElemNumCode: integer
(int64)
-
revenueBasisItem: object
RevenueBasisItemJXB
-
subscriptionCycle: string
Allowed Values:
[ "ANNUAL", "BIMONTHLY", "MONTHLY", "QUARTERLY", "SEMI_ANNUAL" ]
object-
amount: number
(double)
-
currencyBalElemNumCode: integer
(int64)
-
milestoneType: string
Allowed Values:
[ "FUTURE", "IMMEDIATE" ] -
quantity: number
(double)
-
scalable: boolean
-
timeUnit: string
Allowed Values:
[ "DAY", "MONTH", "YEAR" ] -
timeValue: integer
-
type: string
Allowed Values:
[ "RATE_BASED", "VALUE_BASED" ]
object-
key: string
-
unit: string
Allowed Values:
[ "BYTES", "DAYS", "GBYTES", "HOURS", "KBYTES", "MBYTES", "MINUTES", "NONE", "SECONDS" ] -
value: number
(double)
object-
dynamicQuotaBinaryExpression: object
DynamicQuotaBinaryExpressionJXB
-
operator: string
Allowed Values:
[ "EQUAL_TO", "GREATER_THAN", "GREATER_THAN_EQUAL", "LESS_THAN", "LESS_THAN_EQUAL", "NOT_EQUAL_TO" ] -
value: number
(double)
object-
dynamicQuotaBinaryOperator: string
Allowed Values:
[ "ADD", "DIVIDE", "MULTIPLY", "SUBTRACT" ] -
leftOperand: object
DynamicQuotaBinaryOperandExpressionJXB
-
rightOperand: object
DynamicQuotaBinaryOperandExpressionJXB
object-
fieldKind: string
Allowed Values:
[ "CUSTOMER_SPEC_FIELD", "EVENT_SPEC_FIELD", "PRODUCT_SPEC_FIELD", "PROFILE_SPEC_FIELD" ] -
fieldName: string
-
fieldValue: string
-
operator: string
Allowed Values:
[ "CONTAINS", "EQUAL_TO", "GREATER_THAN", "GREATER_THAN_EQUAL", "IN_LIST", "LESS_THAN", "LESS_THAN_EQUAL", "NOT_EQUAL_TO" ] -
separator: string
object-
dynamicQuotaBinaryExpression: object
DynamicQuotaBinaryExpressionJXB
-
dynamicQuotaNumberExpression: object
DynamicQuotaNumberExpressionJXB
-
fieldName: string
-
unit: string
Allowed Values:
[ "BYTES", "DAYS", "GBYTES", "HOURS", "KBYTES", "MBYTES", "MINUTES", "NONE", "SECONDS" ]
object-
day: integer
(int32)
-
month: string
Allowed Values:
[ "APR", "AUG", "DEC", "FEB", "JAN", "JUL", "JUN", "MAR", "MAY", "NOV", "OCT", "SEP" ] -
name: string
-
year: integer
(int32)
object-
applicableToAllBalImpact: boolean
-
applicableToAllChildEvents: boolean
-
applicableToAllChildServices: boolean
-
applicableToName: string
-
description: string
-
eventSpecName: string
-
externalID: string
-
internalId: string
-
itemGroup: string
-
itemSpec: array
itemSpec
-
name: string
-
newName: string
-
obsolete: boolean
-
priceListName: string
-
rule: array
rule
object-
aggregationType: string
Allowed Values:
[ "CUMULATIVE_NONPRECREATE", "CUMULATIVE_PRECREATE", "INDIVIDUAL_NONPRECREATE" ] -
category: string
-
default: boolean
-
description: string
-
externalID: string
-
internalId: string
-
name: string
-
newName: string
-
obsolete: boolean
-
priceListName: string
-
type: string
object-
fieldKind: string
Allowed Values:
[ "CHARGING_RESULT_SPEC", "CUSTOMER_SPEC_FIELD", "EVENT_SPEC_FIELD", "PRODUCT_SPEC_FIELD", "PROFILE_SPEC_FIELD" ] -
fieldName: string
-
fieldValue: string
-
operation: string
Allowed Values:
[ "EQUAL_TO", "GREATER_THAN", "GREATER_THAN_EQUAL", "IN_LIST", "LESS_THAN", "LESS_THAN_EQUAL", "NOT_EQUAL_TO", "REGEX" ] -
separator: string
object-
balanceElementNumCode: string
-
CounterRanges: array
CounterRanges
-
label: string
-
unit: string
Allowed Values:
[ "BYTE", "DAY", "GIGABYTE", "HOUR", "KILOBYTE", "MEGABYTE", "MINUTE", "MONTH", "NONE", "SECOND" ]Measures the RUM quantity.
object-
permittedNames: array
permittedNames
-
resourceId: integer
(int64)
-
resourceUnitType: string
Allowed Values:
[ "BYTE", "KILOBYTE", "MEGABYTE", "GIGABYTE", "DAY", "HOUR", "MINUTE", "SECOND", "AMOUNT_USED", "FIXED_CHARGE", "ANY" ] -
ruleType: string
Allowed Values:
[ "ANY", "LIST", "RANGE" ] -
ruleValue: string
object-
description: string
-
externalID: string
-
internalId: string
-
name: string
-
newName: string
-
obsolete: boolean
-
priceListName: string
-
pricingObjectType: string
Allowed Values:
[ "ALL", "ALTERATION_EXCLUSION", "ALTERATION_OFFERING", "ALTERATION_RATE_PLAN", "ALTERATION_RATE_PLAN_SELECTOR", "APN_MAP", "BEST_PRICING", "BUNDLED_PRODUCT_OFFERING", "BUNDLE_DEPENDENCY", "BUNDLE_TRANSITION", "CHARGE_OFFERING", "CHARGE_RATE_PLAN", "CHARGE_RATE_PLAN_SELECTOR", "CHARGE_SELECTOR_SPEC", "DISTRIBUTION_OFFERING", "DISTRIBUTION_RATE_PLAN", "GENERIC_SELECTOR", "HOLIDAY_CALENDAR", "NONE", "PACKAGE_EXCLUSION", "PACKAGE_LIST", "PACKAGE_OBJ", "PACKAGE_TRANSITION", "PRICE_MODEL", "PRICE_MODEL_SELECTOR", "REPLACEMENT_POP_MODEL", "ROLLOVER_RATE_PLAN", "SUBSCRIPTION_TERMS", "SUBSCRIPTION_TERMS_AUTO_RENEW", "TAX_EXEMPTION_SELECTOR", "TAX_SELECTOR", "TIME_MODEL", "TRIGGER_SPEC", "USC_MAP" ] -
productSpecCharacteristics: array
productSpecCharacteristics
array-
Array of:
object ProductSpecCharacteristicJXB
Key-value pair for defining special characteristics in a product.
object-
name(required): string
Title:
product spec char nameName of the special characteristic. -
value(required): array
product spec char values
Title:
product spec char valuesList of special characteristics added for a given name.
arrayproduct spec char valuesobject-
description: string
-
externalID: string
-
internalId: string
-
name: string
-
newName: string
-
obsolete: boolean
-
priceListName: string
-
rumCode: string
-
rumRounding: string
Allowed Values:
[ "HALF_DOWN", "HALF_UP", "NONE", "ROUND_DOWN", "ROUND_UP" ] -
rumType: string
Allowed Values:
[ "CONDITIONAL", "PARTIAL", "WHOLE" ] -
unit: string
Allowed Values:
[ "BYTE", "DAY", "GIGABYTE", "HOUR", "KILOBYTE", "MEGABYTE", "MINUTE", "MONTH", "NONE", "SECOND" ]Measures the RUM quantity.
object-
code: string
-
description: string
-
externalID: string
-
glIdName: string
-
internalId: string
-
name: string
-
newName: string
-
obsolete: boolean
-
priceListName: string
-
taxCodeValidityPeriods: array
taxCodeValidityPeriods
-
taxPackageType: string
Allowed Values:
[ "CUSTOM", "VERTEX_COMMTAX_21", "VERTEX_QUANTUM" ]
object-
description: string
-
percent: number
(double)
-
salesIndicator: string
Allowed Values:
[ "RESALE", "SALE" ] -
taxJurisdictionLevel: string
Allowed Values:
[ "CITY", "COUNTY", "FEDERAL", "LOCATION", "STATE" ] -
taxJurisdictions: array
taxJurisdictions
-
taxRuleType: string
Allowed Values:
[ "INCLUSIVE", "NCS", "NCT", "STANDARD", "TAX" ] -
transSubType_ServiceCode: integer
-
transType_CategoryCode_Rate: integer
object-
jurisdiction: string
Allowed Values:
[ "CITY", "COUNTY", "FEDERAL", "LOCATION", "STATE" ] -
percent: number
(double)
-
validFrom: string
-
validTo: string
object-
description: string
-
externalID: string
-
internalId: string
-
name: string
-
newName: string
-
obsolete: boolean
-
priceListName: string
-
result: string
-
resultType: string
Allowed Values:
[ "BASE_RESULT", "DERIVED_RESULT" ]
400 Response
500 Response
Examples
-
Example 1: Retrieve all Zone Models and their Referenced Objects
-
Example 2: Retrieve all Zone Models without their Referenced Objects
Example 1: Retrieve all Zone Models and their Referenced Objects
This example shows how to retrieve all zone models and their referenced objects by submitting a GET request on the REST resource using cURL. For more information about cURL, see Use cURL.
curl -X GET 'http://hostname:port/pdc/config?type=STANDARD_ZONE_MODEL&includeReferences=true'
Example of Response Body
If successful, the response code 200 is returned with a response body. The following sample shows the contents of the response body in JSON format.
{
"zoneResultConfiguration": [
{
"name": "ic5",
"internalId": "e5e6ef31-f289-4291-935c-19c9d70c84f6",
"priceListName": "Default",
"obsolete": false,
"result": "ic5",
"resultType": "BASE_RESULT"
}
],
"standardZoneModel": [
{
"name": "sampleZM1",
"internalId": "b802b3f5-5f83-43bc-ab5d-db814bf1283d",
"priceListName": "Default",
"obsolete": false,
"zoneItem": [
{
"productName": "TelcoGsmTelephony",
"originPrefix": "00",
"destinationPrefix": "01",
"validFrom": "0",
"validTo": "inf",
"zoneResult": {
"zoneName": "ic5"
}
}
]
}
]
}
Example 2: Retrieve all Zone Models without their Referenced Objects
This example shows how to retrieve all zone models without their referenced objects by submitting a GET request on the REST resource using cURL. For more information about cURL, see Use cURL.
curl -X GET 'http://hostname:port/pdc/config?type=STANDARD_ZONE_MODEL&includeReferences=false'
Example of Response Body
If successful, the response code 200 is returned with a response body. The following sample shows the contents of the response body in JSON format.
{
"standardZoneModel": [
{
"name": "sampleZM1",
"internalId": "b802b3f5-5f83-43bc-ab5d-db814bf1283d",
"priceListName": "Default",
"obsolete": false,
"zoneItem": [
{
"productName": "TelcoGsmTelephony",
"originPrefix": "00",
"destinationPrefix": "01",
"validFrom": "0",
"validTo": "inf",
"zoneResult": {
"zoneName": "ic5"
}
}
]
}
]
}
Example 3: Retrieve all Zone Models by Name and Type
This example shows how to retrieve all zone models by their name and type by submitting a GET request on the REST resource using cURL. For more information about cURL, see Use cURL.
curl -X GET 'http://hostname:port/pdc/config?name=sampleZM1&type=STANDARD_ZONE_MODEL'
Example of Response Body
If successful, the response code 200 is returned with a response body. The following sample shows the contents of the response body in JSON format.
{
"standardZoneModel": [
{
"name": "sampleZM1",
"internalId": "b802b3f5-5f83-43bc-ab5d-db814bf1283d",
"priceListName": "Default",
"obsolete": false,
"zoneItem": [
{
"productName": "TelcoGsmTelephony",
"originPrefix": "00",
"destinationPrefix": "01",
"validFrom": "0",
"validTo": "inf",
"zoneResult": {
"zoneName": "ic5"
}
}
]
}
]
}
Example 4: Retrieve all Business Configuration Objects
This example shows how to retrieve all business configuration objects by submitting a GET request on the REST resource using cURL. For more information about cURL, see Use cURL.
curl -X GET 'http://hostname:port/pdc/config?name=sampleZM1&type=STANDARD_ZONE_MODEL'
Example of Response Body
If successful, the response code 200 is returned with a response body. The following sample shows the contents of the response body in JSON format.
{
"taxCodes": [
{
"name": "user_code",
"description": "user_code",
"internalId": "99aecded-f9b9-432b-bfda-0d1b8f7dc9e8",
"priceListName": "Default",
"obsolete": false,
"code": "user_code",
"taxPackageType": "CUSTOM",
"taxCodeValidityPeriods": [
{
"validFrom": "19700101",
"validTo": "20380101",
"taxCodeMaps": [
{
"description": "user_code",
"percent": 10.0,
"taxJurisdictionLevel": "FEDERAL",
"taxJurisdictions": [
"*"
],
"taxRuleType": "STANDARD"
}
]
}
]
},
{
"name": "ct_toll",
"description": "ct_toll",
"internalId": "b67eb858-ff1f-4c85-bff7-2a951c08ca54",
"priceListName": "Default",
"obsolete": false,
"code": "ct_toll",
"taxPackageType": "VERTEX_COMMTAX_21",
"taxCodeValidityPeriods": [
{
"taxCodeMaps": [
{
"transTypeCategoryCodeRate": 4,
"transSubTypeServiceCode": 2,
"salesIndicator": "SALE"
}
]
}
]
},
{
"name": "qt_cycle",
"description": "qt_cycle",
"internalId": "f78a13cf-0436-41f8-a4ab-343392f7340a",
"priceListName": "Default",
"obsolete": false,
"code": "qt_cycle",
"taxPackageType": "VERTEX_QUANTUM",
"taxCodeValidityPeriods": [
{
"taxCodeMaps": [
{
"transTypeCategoryCodeRate": 1,
"transSubTypeServiceCode": 1,
"salesIndicator": "SALE"
}
]
}
]
},
{
"name": "ct_direct",
"description": "ct_direct",
"internalId": "5ad98687-59e8-4acb-8caf-b1cdaf6ef6d9",
"priceListName": "Default",
"obsolete": false,
"code": "ct_direct",
"taxPackageType": "VERTEX_COMMTAX_21",
"taxCodeValidityPeriods": [
{
"taxCodeMaps": [
{
"transTypeCategoryCodeRate": 1,
"transSubTypeServiceCode": 1,
"salesIndicator": "SALE"
}
]
}
]
},
{
"name": "usage",
"description": "usage",
"internalId": "c6b66573-51be-4f57-85a4-312c4be22fe3",
"priceListName": "Default",
"obsolete": false,
"code": "usage",
"taxPackageType": "CUSTOM",
"taxCodeValidityPeriods": [
{
"validFrom": "20010201",
"validTo": "20300131",
"taxCodeMaps": [
{
"description": "USF",
"percent": 4.0,
"taxJurisdictionLevel": "FEDERAL",
"taxJurisdictions": [
"US"
],
"taxRuleType": "STANDARD"
}
]
}
]
},
{
"name": "purchase",
"description": "purchase",
"internalId": "63d56748-a664-4af4-ad02-f90c4de12eed",
"priceListName": "Default",
"obsolete": false,
"code": "purchase",
"taxPackageType": "CUSTOM",
"taxCodeValidityPeriods": [
{
"validFrom": "20010201",
"validTo": "20300131",
"taxCodeMaps": [
{
"description": "Sales",
"percent": 6.0,
"taxJurisdictionLevel": "STATE",
"taxJurisdictions": [
"CA"
],
"taxRuleType": "STANDARD"
},
{
"description": "Sales",
"percent": 1.25,
"taxJurisdictionLevel": "COUNTY",
"taxJurisdictions": [
"*"
],
"taxRuleType": "STANDARD"
},
{
"description": "Sales",
"percent": 1.0,
"taxJurisdictionLevel": "CITY",
"taxJurisdictions": [
"*"
],
"taxRuleType": "STANDARD"
}
]
}
]
},
{
"name": "VAT",
"description": "VAT",
"internalId": "85f28e69-5282-48bb-8db0-4532bbfafcab",
"priceListName": "Default",
"obsolete": false,
"code": "VAT",
"taxPackageType": "CUSTOM",
"taxCodeValidityPeriods": [
{
"validFrom": "20020201",
"validTo": "20300131",
"taxCodeMaps": [
{
"description": "VAT-EU",
"percent": 5.0,
"taxJurisdictionLevel": "FEDERAL",
"taxJurisdictions": [
"GB",
"FR"
],
"taxRuleType": "STANDARD"
},
{
"description": "VAT-GB",
"percent": 4.5,
"taxJurisdictionLevel": "FEDERAL",
"taxJurisdictions": [
"GB"
],
"taxRuleType": "STANDARD"
},
{
"description": "VAT-FR",
"percent": 4.0,
"taxJurisdictionLevel": "FEDERAL",
"taxJurisdictions": [
"FR"
],
"taxRuleType": "STANDARD"
}
]
}
]
},
{
"name": "cycle",
"description": "cycle",
"internalId": "f3490271-f02b-471a-9115-fe7b586776f9",
"priceListName": "Default",
"obsolete": false,
"code": "cycle",
"taxPackageType": "CUSTOM",
"taxCodeValidityPeriods": [
{
"validFrom": "20010201",
"validTo": "20300131",
"taxCodeMaps": [
{
"description": "Excise",
"percent": 3.5,
"taxJurisdictionLevel": "FEDERAL",
"taxJurisdictions": [
"US"
],
"taxRuleType": "STANDARD"
}
]
}
]
},
{
"name": "toll",
"description": "toll",
"internalId": "024dc84a-31bd-4786-b6f3-bce5d2eee20b",
"priceListName": "Default",
"obsolete": false,
"code": "toll",
"taxPackageType": "CUSTOM",
"taxCodeValidityPeriods": [
{
"validFrom": "20010201",
"validTo": "20300131",
"taxCodeMaps": [
{
"description": "TRS",
"percent": 2.0,
"taxJurisdictionLevel": "FEDERAL",
"taxJurisdictions": [
"US"
],
"taxRuleType": "TAX"
},
{
"description": "911",
"percent": 1.5,
"taxJurisdictionLevel": "STATE",
"taxJurisdictions": [
"CA"
],
"taxRuleType": "TAX"
},
{
"description": "B-O",
"percent": 2.0,
"taxJurisdictionLevel": "STATE",
"taxJurisdictions": [
"CA"
],
"taxRuleType": "TAX"
},
{
"description": "Deaf",
"percent": 3.15,
"taxJurisdictionLevel": "CITY",
"taxJurisdictions": [
"Cupertino"
],
"taxRuleType": "TAX"
}
]
}
]
},
{
"name": "qt_usage",
"description": "qt_usage",
"internalId": "f817075d-1b9e-4e0a-9f32-315c4f05aaf3",
"priceListName": "Default",
"obsolete": false,
"code": "qt_usage",
"taxPackageType": "VERTEX_QUANTUM",
"taxCodeValidityPeriods": [
{
"taxCodeMaps": [
{
"transTypeCategoryCodeRate": 1,
"transSubTypeServiceCode": 1,
"salesIndicator": "SALE"
}
]
}
]
},
{
"name": "TAX001",
"description": "TAX001",
"internalId": "c9521258-074e-459e-ba77-c99dfebf00ec",
"priceListName": "Default",
"obsolete": false,
"code": "TAX001",
"taxPackageType": "CUSTOM",
"taxCodeValidityPeriods": [
{
"validFrom": "19700101",
"validTo": "20380101",
"taxCodeMaps": [
{
"description": "taxCode",
"percent": 0.5,
"taxJurisdictionLevel": "FEDERAL",
"taxJurisdictions": [
"*"
],
"taxRuleType": "STANDARD"
}
]
}
]
},
{
"name": "TAX002",
"description": "TAX002",
"internalId": "b53e89f5-9c6b-4dfa-8d41-3adf9a10ed97",
"priceListName": "Default",
"obsolete": false,
"code": "TAX002",
"taxPackageType": "CUSTOM",
"taxCodeValidityPeriods": [
{
"validFrom": "19700101",
"validTo": "20380101",
"taxCodeMaps": [
{
"description": "Tax002 desc",
"percent": 0.5,
"taxJurisdictionLevel": "FEDERAL",
"taxJurisdictions": [
"*"
],
"taxRuleType": "STANDARD"
}
]
}
]
}
],
"taxExemptionCodes": [
{
"name": "sampleRule",
"internalId": "9dcabeac-c469-4595-9874-b4536ed78f25",
"priceListName": "Default",
"obsolete": false,
"code": "toll",
"taxExemptionCodeMaps": [
{
"validFrom": "19700101",
"validTo": "20380101",
"percent": 0.5,
"jurisdiction": "CITY"
}
]
},
{
"name": "tec1",
"description": "tec desc",
"internalId": "237cd0e5-736c-4f80-9340-7702b93e8f66",
"priceListName": "Default",
"obsolete": false,
"code": "TEC002",
"taxExemptionCodeMaps": [
{
"validFrom": "19700101",
"validTo": "20380101",
"percent": 0.5,
"jurisdiction": "CITY"
}
]
}
],
"zoneResultConfiguration": [
{
"name": "ic5",
"internalId": "e5e6ef31-f289-4291-935c-19c9d70c84f6",
"priceListName": "Default",
"obsolete": false,
"result": "ic5",
"resultType": "BASE_RESULT"
},
{
"name": "ic6",
"description": "ic6 des",
"internalId": "76275ff3-df98-485d-a3b9-9956cdaef5e0",
"priceListName": "Default",
"obsolete": false,
"result": "ic6",
"resultType": "DERIVED_RESULT"
}
],
"holidayCalendar": [
{
"name": "special_cal",
"internalId": "22f98575-20b2-4a60-b458-34345ea51787",
"priceListName": "Default",
"obsolete": false,
"holiday": [
{
"name": "May 03",
"month": "MAY",
"day": 3
}
]
}
],
"balanceElements": [
{
"name": "Australian Dollar",
"description": "Australian Dollar",
"internalId": "7f5d2621-be65-4853-9011-3b8ff676ed7e",
"priceListName": "Default",
"obsolete": false,
"code": "AUD",
"numericCode": 36,
"symbol": "$",
"transientElement": false,
"foldable": true,
"counter": false,
"expiryNotification": true,
"roundingRules": [
{
"precision": 2,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "CHARGING"
},
{
"precision": 2,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "ALTERATION"
},
{
"precision": 2,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "TAXATION"
},
{
"precision": 2,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "AR"
}
],
"consumptionRule": "NONE"
},
{
"name": "Austrian Schilling",
"description": "Austrian Schilling",
"internalId": "3acd870f-2267-49cb-a912-862807983980",
"priceListName": "Default",
"obsolete": false,
"code": "ATS",
"numericCode": 40,
"symbol": "oS",
"transientElement": false,
"foldable": true,
"counter": false,
"expiryNotification": true,
"roundingRules": [
{
"precision": 3,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "CHARGING"
},
{
"precision": 3,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "ALTERATION"
},
{
"precision": 3,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "TAXATION"
},
{
"precision": 3,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "AR"
}
],
"consumptionRule": "NONE"
},
{
"name": "Belgian Franc",
"description": "Belgian Franc",
"internalId": "a189eb83-f852-4a13-9db1-ee41e21f5c77",
"priceListName": "Default",
"obsolete": false,
"code": "BEF",
"numericCode": 56,
"symbol": "BF",
"transientElement": false,
"foldable": true,
"counter": false,
"expiryNotification": true,
"roundingRules": [
{
"precision": 3,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "CHARGING"
},
{
"precision": 3,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "ALTERATION"
},
{
"precision": 3,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "TAXATION"
},
{
"precision": 3,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "AR"
}
],
"consumptionRule": "NONE"
},
{
"name": "Canadian Dollar",
"description": "Canadian Dollar",
"internalId": "602a9372-e0c7-4780-bbf3-e826d13d3d50",
"priceListName": "Default",
"obsolete": false,
"code": "CAD",
"numericCode": 124,
"symbol": "Can$",
"transientElement": false,
"foldable": true,
"counter": false,
"expiryNotification": true,
"roundingRules": [
{
"precision": 2,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "CHARGING"
},
{
"precision": 2,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "ALTERATION"
},
{
"precision": 2,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "TAXATION"
},
{
"precision": 2,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "AR"
}
],
"consumptionRule": "NONE"
},
{
"name": "Finnish Markka",
"description": "Finnish Markka",
"internalId": "f14a4fa9-f866-4c42-b1e2-03079ccca1e7",
"priceListName": "Default",
"obsolete": false,
"code": "FIM",
"numericCode": 246,
"symbol": "mk",
"transientElement": false,
"foldable": true,
"counter": false,
"expiryNotification": true,
"roundingRules": [
{
"precision": 3,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "CHARGING"
},
{
"precision": 3,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "ALTERATION"
},
{
"precision": 3,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "TAXATION"
},
{
"precision": 3,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "AR"
}
],
"consumptionRule": "NONE"
},
{
"name": "French Franc",
"description": "French Franc",
"internalId": "20d92b74-b734-4272-92fe-84d9d596e72a",
"priceListName": "Default",
"obsolete": false,
"code": "FRF",
"numericCode": 250,
"symbol": "F",
"transientElement": false,
"foldable": true,
"counter": false,
"expiryNotification": true,
"roundingRules": [
{
"precision": 3,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "CHARGING"
},
{
"precision": 3,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "ALTERATION"
},
{
"precision": 3,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "TAXATION"
},
{
"precision": 3,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "AR"
}
],
"consumptionRule": "NONE"
},
{
"name": "Deutsche Mark",
"description": "Deutsche Mark",
"internalId": "ae1b2ca3-6683-4505-95f7-f67c891a45b0",
"priceListName": "Default",
"obsolete": false,
"code": "DEM",
"numericCode": 280,
"symbol": "DM",
"transientElement": false,
"foldable": true,
"counter": false,
"expiryNotification": true,
"roundingRules": [
{
"precision": 3,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "CHARGING"
},
{
"precision": 3,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "ALTERATION"
},
{
"precision": 3,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "TAXATION"
},
{
"precision": 3,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "AR"
}
],
"consumptionRule": "NONE"
},
{
"name": "Greek Drachma",
"description": "Greek Drachma",
"internalId": "ca9954fd-b0f5-4dc0-ac1c-0dc629392737",
"priceListName": "Default",
"obsolete": false,
"code": "GRD",
"numericCode": 300,
"symbol": "Dr",
"transientElement": false,
"foldable": true,
"counter": false,
"expiryNotification": true,
"roundingRules": [
{
"precision": 3,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "CHARGING"
},
{
"precision": 3,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "ALTERATION"
},
{
"precision": 3,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "TAXATION"
},
{
"precision": 3,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "AR"
}
],
"consumptionRule": "NONE"
},
{
"name": "Irish Pound",
"description": "Irish Pound",
"internalId": "0eb1c5bf-6b8f-4364-920e-6f0c981d0033",
"priceListName": "Default",
"obsolete": false,
"code": "IEP",
"numericCode": 372,
"symbol": "IRL",
"transientElement": false,
"foldable": true,
"counter": false,
"expiryNotification": true,
"roundingRules": [
{
"precision": 3,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "CHARGING"
},
{
"precision": 3,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "ALTERATION"
},
{
"precision": 3,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "TAXATION"
},
{
"precision": 3,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "AR"
}
],
"consumptionRule": "NONE"
},
{
"name": "Italian Lira",
"description": "Italian Lira",
"internalId": "3cf8c328-7f88-473c-a88b-28de2de2fa2a",
"priceListName": "Default",
"obsolete": false,
"code": "ITL",
"numericCode": 380,
"symbol": "L.",
"transientElement": false,
"foldable": true,
"counter": false,
"expiryNotification": true,
"roundingRules": [
{
"precision": 3,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "CHARGING"
},
{
"precision": 3,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "ALTERATION"
},
{
"precision": 3,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "TAXATION"
},
{
"precision": 3,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "AR"
}
],
"consumptionRule": "NONE"
},
{
"name": "Japanese Yen",
"description": "Japanese Yen",
"internalId": "6ad22557-9322-4a4b-bf42-87de6702c1ce",
"priceListName": "Default",
"obsolete": false,
"code": "JPY",
"numericCode": 392,
"symbol": "Yen",
"transientElement": false,
"foldable": true,
"counter": false,
"expiryNotification": true,
"roundingRules": [
{
"precision": 2,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "CHARGING"
},
{
"precision": 2,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "ALTERATION"
},
{
"precision": 2,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "TAXATION"
},
{
"precision": 2,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "AR"
}
],
"consumptionRule": "NONE"
},
{
"name": "Luxembourg Franc",
"description": "Luxembourg Franc",
"internalId": "9c5e6d47-9711-4cb8-a22c-e3fc2ba55eb0",
"priceListName": "Default",
"obsolete": false,
"code": "LUF",
"numericCode": 442,
"symbol": "LuxF",
"transientElement": false,
"foldable": true,
"counter": false,
"expiryNotification": true,
"roundingRules": [
{
"precision": 3,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "CHARGING"
},
{
"precision": 3,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "ALTERATION"
},
{
"precision": 3,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "TAXATION"
},
{
"precision": 3,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "AR"
}
],
"consumptionRule": "NONE"
},
{
"name": "Netherlands Guilder",
"description": "Netherlands Guilder",
"internalId": "4cc9270a-6873-4056-89f3-b025e2bd2558",
"priceListName": "Default",
"obsolete": false,
"code": "NLG",
"numericCode": 528,
"symbol": "f.",
"transientElement": false,
"foldable": true,
"counter": false,
"expiryNotification": true,
"roundingRules": [
{
"precision": 3,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "CHARGING"
},
{
"precision": 3,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "ALTERATION"
},
{
"precision": 3,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "TAXATION"
},
{
"precision": 3,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "AR"
}
],
"consumptionRule": "NONE"
},
{
"name": "Portugese Escudo",
"description": "Portugese Escudo",
"internalId": "62240899-49f7-4abc-b175-31c360994203",
"priceListName": "Default",
"obsolete": false,
"code": "PTE",
"numericCode": 620,
"symbol": "Esc.",
"transientElement": false,
"foldable": true,
"counter": false,
"expiryNotification": true,
"roundingRules": [
{
"precision": 3,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "CHARGING"
},
{
"precision": 3,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "ALTERATION"
},
{
"precision": 3,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "TAXATION"
},
{
"precision": 3,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "AR"
}
],
"consumptionRule": "NONE"
},
{
"name": "Spanish Peseta",
"description": "Spanish Peseta",
"internalId": "36f03096-c842-49ac-aa32-26a325a113f4",
"priceListName": "Default",
"obsolete": false,
"code": "ESP",
"numericCode": 724,
"symbol": "Pts",
"transientElement": false,
"foldable": true,
"counter": false,
"expiryNotification": true,
"roundingRules": [
{
"precision": 3,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "CHARGING"
},
{
"precision": 3,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "ALTERATION"
},
{
"precision": 3,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "TAXATION"
},
{
"precision": 3,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "AR"
}
],
"consumptionRule": "NONE"
},
{
"name": "Swiss Franc",
"description": "Swiss Franc",
"internalId": "63aac5ad-7488-4cb9-8384-b472dedc8c5e",
"priceListName": "Default",
"obsolete": false,
"code": "CHF",
"numericCode": 756,
"symbol": "SFr.",
"transientElement": false,
"foldable": true,
"counter": false,
"expiryNotification": true,
"roundingRules": [
{
"precision": 2,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "CHARGING"
},
{
"precision": 2,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "ALTERATION"
},
{
"precision": 2,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "TAXATION"
},
{
"precision": 2,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "AR"
}
],
"consumptionRule": "NONE"
},
{
"name": "British Pound Sterling",
"description": "British Pound Sterling",
"internalId": "69848d39-235c-41e2-8343-4e45d6de328c",
"priceListName": "Default",
"obsolete": false,
"code": "GBP",
"numericCode": 826,
"symbol": "L",
"transientElement": false,
"foldable": true,
"counter": false,
"expiryNotification": true,
"roundingRules": [
{
"precision": 2,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "CHARGING"
},
{
"precision": 2,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "ALTERATION"
},
{
"precision": 2,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "TAXATION"
},
{
"precision": 2,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "AR"
}
],
"consumptionRule": "NONE"
},
{
"name": "US Dollar",
"description": "US Dollar",
"internalId": "bb1db709-3554-407d-b474-15cc30bae720",
"priceListName": "Default",
"obsolete": false,
"code": "USD",
"numericCode": 840,
"symbol": "$",
"transientElement": false,
"foldable": true,
"counter": false,
"expiryNotification": true,
"roundingRules": [
{
"precision": 2,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "CHARGING"
},
{
"precision": 2,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "ALTERATION"
},
{
"precision": 2,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "TAXATION"
},
{
"precision": 2,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "AR"
}
],
"consumptionRule": "NONE"
},
{
"name": "Euro",
"description": "Euro",
"internalId": "b8384467-ffba-4713-b6fa-df575b57d560",
"priceListName": "Default",
"obsolete": false,
"code": "EUR",
"numericCode": 978,
"symbol": "E",
"transientElement": false,
"foldable": true,
"counter": false,
"expiryNotification": true,
"roundingRules": [
{
"precision": 3,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "CHARGING"
},
{
"precision": 3,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "ALTERATION"
},
{
"precision": 3,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "TAXATION"
},
{
"precision": 3,
"toleranceMin": 0.01,
"toleranceMax": 0.05,
"tolerancePercentage": 0.04,
"roundingMode": "NEAREST",
"processingStage": "AR"
}
],
"consumptionRule": "NONE"
},
{
"name": "Free Minutes",
"description": "Free Minutes",
"internalId": "5251bf07-e75c-4cdb-89bb-83de3b0a24d4",
"priceListName": "Default",
"obsolete": false,
"code": "FMN",
"numericCode": 100002,
"symbol": "FMN",
"transientElement": false,
"foldable": true,
"counter": false,
"expiryNotification": true,
"roundingRules": [
{
"precision": 5,
"toleranceMin": 0.0,
"toleranceMax": 0.0,
"tolerancePercentage": 0.0,
"roundingMode": "NEAREST",
"processingStage": "CHARGING"
},
{
"precision": 5,
"toleranceMin": 0.0,
"toleranceMax": 0.0,
"tolerancePercentage": 0.0,
"roundingMode": "NEAREST",
"processingStage": "ALTERATION"
},
{
"precision": 5,
"toleranceMin": 0.0,
"toleranceMax": 0.0,
"tolerancePercentage": 0.0,
"roundingMode": "NEAREST",
"processingStage": "TAXATION"
},
{
"precision": 5,
"toleranceMin": 0.0,
"toleranceMax": 0.0,
"tolerancePercentage": 0.0,
"roundingMode": "NEAREST",
"processingStage": "AR"
}
],
"consumptionRule": "NONE"
},
{
"name": "Frequent Flier Miles",
"description": "Frequent Flier Miles",
"internalId": "7676a523-180e-4717-a7dd-450852804e84",
"priceListName": "Default",
"obsolete": false,
"code": "MIL",
"numericCode": 1000003,
"symbol": "Mil",
"transientElement": false,
"foldable": true,
"counter": false,
"expiryNotification": true,
"roundingRules": [
{
"precision": 0,
"toleranceMin": 0.0,
"toleranceMax": 0.0,
"tolerancePercentage": 0.0,
"roundingMode": "NEAREST",
"processingStage": "CHARGING"
},
{
"precision": 0,
"toleranceMin": 0.0,
"toleranceMax": 0.0,
"tolerancePercentage": 0.0,
"roundingMode": "NEAREST",
"processingStage": "ALTERATION"
},
{
"precision": 0,
"toleranceMin": 0.0,
"toleranceMax": 0.0,
"tolerancePercentage": 0.0,
"roundingMode": "NEAREST",
"processingStage": "TAXATION"
},
{
"precision": 0,
"toleranceMin": 0.0,
"toleranceMax": 0.0,
"tolerancePercentage": 0.0,
"roundingMode": "NEAREST",
"processingStage": "AR"
}
],
"consumptionRule": "NONE"
},
{
"name": "Free Game",
"description": "Free Game",
"internalId": "c2240b53-c906-43e5-b876-1d9b7c2f1c14",
"priceListName": "Default",
"obsolete": false,
"code": "GAM",
"numericCode": 1000004,
"symbol": "Gam",
"transientElement": false,
"foldable": true,
"counter": false,
"expiryNotification": true,
"roundingRules": [
{
"precision": 0,
"toleranceMin": 0.0,
"toleranceMax": 0.0,
"tolerancePercentage": 0.0,
"roundingMode": "NEAREST",
"processingStage": "CHARGING"
},
{
"precision": 0,
"toleranceMin": 0.0,
"toleranceMax": 0.0,
"tolerancePercentage": 0.0,
"roundingMode": "NEAREST",
"processingStage": "ALTERATION"
},
{
"precision": 0,
"toleranceMin": 0.0,
"toleranceMax": 0.0,
"tolerancePercentage": 0.0,
"roundingMode": "NEAREST",
"processingStage": "TAXATION"
},
{
"precision": 0,
"toleranceMin": 0.0,
"toleranceMax": 0.0,
"tolerancePercentage": 0.0,
"roundingMode": "NEAREST",
"processingStage": "AR"
}
],
"consumptionRule": "NONE"
},
{
"name": "MB Used",
"description": "MegaByte Used",
"internalId": "07e6b53e-4fa7-4e6b-a105-7f1af9efde83",
"priceListName": "Default",
"obsolete": false,
"code": "MBU",
"numericCode": 1000009,
"symbol": "Mbu",
"transientElement": false,
"foldable": true,
"counter": false,
"expiryNotification": true,
"roundingRules": [
{
"precision": 0,
"toleranceMin": 0.0,
"toleranceMax": 0.0,
"tolerancePercentage": 0.0,
"roundingMode": "NEAREST",
"processingStage": "CHARGING"
},
{
"precision": 0,
"toleranceMin": 0.0,
"toleranceMax": 0.0,
"tolerancePercentage": 0.0,
"roundingMode": "NEAREST",
"processingStage": "ALTERATION"
},
{
"precision": 0,
"toleranceMin": 0.0,
"toleranceMax": 0.0,
"tolerancePercentage": 0.0,
"roundingMode": "NEAREST",
"processingStage": "TAXATION"
},
{
"precision": 0,
"toleranceMin": 0.0,
"toleranceMax": 0.0,
"tolerancePercentage": 0.0,
"roundingMode": "NEAREST",
"processingStage": "AR"
}
],
"consumptionRule": "NONE"
},
{
"name": "Free Domestic Minutes",
"description": "Free Domestic Minutes",
"internalId": "7f0b4aae-1da3-4cd3-976f-25b06fb84a2c",
"priceListName": "Default",
"obsolete": false,
"code": "FDM",
"numericCode": 1000010,
"symbol": "FDM",
"transientElement": false,
"foldable": true,
"counter": false,
"expiryNotification": true,
"roundingRules": [
{
"precision": 1,
"toleranceMin": 0.0,
"toleranceMax": 0.0,
"tolerancePercentage": 0.0,
"roundingMode": "NEAREST",
"processingStage": "CHARGING"
},
{
"precision": 1,
"toleranceMin": 0.0,
"toleranceMax": 0.0,
"tolerancePercentage": 0.0,
"roundingMode": "NEAREST",
"processingStage": "ALTERATION"
},
{
"precision": 1,
"toleranceMin": 0.0,
"toleranceMax": 0.0,
"tolerancePercentage": 0.0,
"roundingMode": "NEAREST",
"processingStage": "TAXATION"
},
{
"precision": 1,
"toleranceMin": 0.0,
"toleranceMax": 0.0,
"tolerancePercentage": 0.0,
"roundingMode": "NEAREST",
"processingStage": "AR"
}
],
"consumptionRule": "NONE"
},
{
"name": "Songs Downloaded",
"description": "Songs Downloaded",
"internalId": "d8184663-c37a-4ab3-a143-7a2378b8adbe",
"priceListName": "Default",
"obsolete": false,
"code": "SON",
"numericCode": 1000019,
"symbol": "Son",
"transientElement": false,
"foldable": true,
"counter": false,
"expiryNotification": true,
"roundingRules": [
{
"precision": 0,
"toleranceMin": 0.0,
"toleranceMax": 0.0,
"tolerancePercentage": 0.0,
"roundingMode": "NEAREST",
"processingStage": "CHARGING"
},
{
"precision": 0,
"toleranceMin": 0.0,
"toleranceMax": 0.0,
"tolerancePercentage": 0.0,
"roundingMode": "NEAREST",
"processingStage": "ALTERATION"
},
{
"precision": 0,
"toleranceMin": 0.0,
"toleranceMax": 0.0,
"tolerancePercentage": 0.0,
"roundingMode": "NEAREST",
"processingStage": "TAXATION"
},
{
"precision": 0,
"toleranceMin": 0.0,
"toleranceMax": 0.0,
"tolerancePercentage": 0.0,
"roundingMode": "NEAREST",
"processingStage": "AR"
}
],
"consumptionRule": "NONE"
},
{
"name": "Loyalty Points",
"description": "Loyalty Points",
"internalId": "b8311447-7aff-43ac-9ef5-223399aea88a",
"priceListName": "Default",
"obsolete": false,
"code": "PTS",
"numericCode": 1000091,
"symbol": "pts",
"transientElement": false,
"foldable": true,
"counter": false,
"expiryNotification": true,
"roundingRules": [
{
"precision": 0,
"toleranceMin": 0.0,
"toleranceMax": 0.0,
"tolerancePercentage": 0.0,
"roundingMode": "NEAREST",
"processingStage": "CHARGING"
},
{
"precision": 0,
"toleranceMin": 0.0,
"toleranceMax": 0.0,
"tolerancePercentage": 0.0,
"roundingMode": "NEAREST",
"processingStage": "ALTERATION"
},
{
"precision": 0,
"toleranceMin": 0.0,
"toleranceMax": 0.0,
"tolerancePercentage": 0.0,
"roundingMode": "NEAREST",
"processingStage": "TAXATION"
},
{
"precision": 0,
"toleranceMin": 0.0,
"toleranceMax": 0.0,
"tolerancePercentage": 0.0,
"roundingMode": "NEAREST",
"processingStage": "AR"
}
],
"consumptionRule": "NONE"
},
{
"name": "Free Seconds",
"description": "Free Seconds",
"internalId": "0abd3b68-33b9-4e00-9ac6-06e1b49b1400",
"priceListName": "Default",
"obsolete": false,
"code": "YES",
"numericCode": 1000095,
"symbol": "MIN",
"transientElement": false,
"foldable": true,
"counter": false,
"expiryNotification": true,
"roundingRules": [
{
"precision": 1,
"toleranceMin": 0.0,
"toleranceMax": 0.0,
"tolerancePercentage": 0.0,
"roundingMode": "NEAREST",
"processingStage": "CHARGING"
},
{
"precision": 1,
"toleranceMin": 0.0,
"toleranceMax": 0.0,
"tolerancePercentage": 0.0,
"roundingMode": "NEAREST",
"processingStage": "ALTERATION"
},
{
"precision": 1,
"toleranceMin": 0.0,
"toleranceMax": 0.0,
"tolerancePercentage": 0.0,
"roundingMode": "NEAREST",
"processingStage": "TAXATION"
},
{
"precision": 1,
"toleranceMin": 0.0,
"toleranceMax": 0.0,
"tolerancePercentage": 0.0,
"roundingMode": "NEAREST",
"processingStage": "AR"
}
],
"consumptionRule": "NONE"
},
{
"name": "Armenian Dram",
"internalId": "b8180db8-857f-4d96-991f-f7f75d466a3f",
"priceListName": "Default",
"obsolete": false,
"code": "AMD",
"numericCode": 51,
"symbol": "AMD",
"transientElement": false,
"foldable": true,
"counter": false,
"expiryNotification": true,
"roundingRules": [
{
"precision": 2,
"toleranceMin": 0.0,
"toleranceMax": 0.0,
"tolerancePercentage": 0.0,
"roundingMode": "NEAREST",
"processingStage": "CHARGING"
},
{
"precision": 2,
"toleranceMin": 0.0,
"toleranceMax": 0.0,
"tolerancePercentage": 0.0,
"roundingMode": "NEAREST",
"processingStage": "ALTERATION"
},
{
"precision": 2,
"toleranceMin": 0.0,
"toleranceMax": 0.0,
"tolerancePercentage": 0.0,
"roundingMode": "NEAREST",
"processingStage": "TAXATION"
},
{
"precision": 2,
"toleranceMin": 0.0,
"toleranceMax": 0.0,
"tolerancePercentage": 0.0,
"roundingMode": "NEAREST",
"processingStage": "AR"
}
],
"consumptionRule": "NONE"
}
],
"rumConfigurations": [
{
"name": "Uplink",
"description": "Uplink",
"internalId": "51561a06-cde7-4ba4-b087-0eb673e7c136",
"priceListName": "Default",
"obsolete": false,
"unit": "KILOBYTE",
"rumType": "PARTIAL",
"rumCode": "Uplink"
},
{
"name": "Duration",
"description": "Duration",
"internalId": "5cc80768-2940-43c6-ba07-62123386ca97",
"priceListName": "Default",
"obsolete": false,
"unit": "SECOND",
"rumType": "PARTIAL",
"rumCode": "Duration"
},
{
"name": "Fold",
"description": "Fold",
"internalId": "5eb4f20d-ccee-45bf-b200-feccdad51256",
"priceListName": "Default",
"obsolete": false,
"unit": "NONE",
"rumType": "WHOLE",
"rumCode": "Fold"
},
{
"name": "Occurrence",
"description": "Occurrence",
"internalId": "bc6cdb27-a9ce-448f-ae57-3765961430b8",
"priceListName": "Default",
"obsolete": false,
"unit": "NONE",
"rumType": "WHOLE",
"rumCode": "Occurrence"
},
{
"name": "Size",
"description": "Size",
"internalId": "a091ecbd-80e8-444b-b1d6-2ffc5685e8ef",
"priceListName": "Default",
"obsolete": false,
"unit": "BYTE",
"rumType": "PARTIAL",
"rumCode": "Size"
},
{
"name": "Amount",
"description": "Amount",
"internalId": "4e039881-b969-4794-9230-e8d5aac21265",
"priceListName": "Default",
"obsolete": false,
"unit": "NONE",
"rumType": "WHOLE",
"rumCode": "Amount"
},
{
"name": "Volume",
"description": "Volume",
"internalId": "325b75a0-83f0-442c-83ff-0456ba6f5466",
"priceListName": "Default",
"obsolete": false,
"unit": "BYTE",
"rumType": "PARTIAL",
"rumCode": "Volume"
},
{
"name": "Messages",
"description": "Messages",
"internalId": "4843f5d4-e638-4a79-85d4-95dc1f5d400f",
"priceListName": "Default",
"obsolete": false,
"unit": "NONE",
"rumType": "WHOLE",
"rumCode": "Messages"
},
{
"name": "DownLink",
"description": "DownLink",
"internalId": "97571620-0591-4372-8187-1e56841dd29c",
"priceListName": "Default",
"obsolete": false,
"unit": "KILOBYTE",
"rumType": "PARTIAL",
"rumCode": "DownLink"
},
{
"name": "PASSTHRU",
"description": "PASSTHRU for Price Override functionality. While associating\n this RUM with Event, user must provide appropriate RUM\n expression which drives Price Override functionality.",
"internalId": "16a4e7de-48b9-4d30-9984-9a766db4a762",
"priceListName": "Default",
"obsolete": false,
"unit": "NONE",
"rumType": "WHOLE",
"rumCode": "PASSTHRU"
}
],
"itemTypeSelectors": [
{
"name": "its1",
"description": "its desc",
"internalId": "71e67e58-c40d-4d45-81e8-5c4b33d6555c",
"priceListName": "Default",
"obsolete": false,
"applicableToName": "TelcoGsmTelephony",
"eventSpecName": "EventBillingProductFeeCycleCycle_forward_monthly",
"itemGroup": "ig",
"applicableToAllChildServices": true,
"applicableToAllChildEvents": true,
"applicableToAllBalImpact": true,
"rule": [
{
"ruleName": "itsRule",
"ruleOrder": 1,
"customExpression": [
{
"expressionName": "*"
}
],
"specName": "is1"
}
],
"itemSpec": [
{
"name": "is1",
"description": " ",
"internalId": "718eefc2-5012-4ddb-997c-c7e34781bc3d",
"priceListName": "Default",
"obsolete": false,
"type": "/item/",
"_default": true,
"aggregationType": "CUMULATIVE_PRECREATE",
"category": "ic"
}
]
}
],
"standardZoneModel": [
{
"name": "sampleZM1",
"internalId": "b802b3f5-5f83-43bc-ab5d-db814bf1283d",
"priceListName": "Default",
"obsolete": false,
"zoneItem": [
{
"productName": "TelcoGsmTelephony",
"originPrefix": "00",
"destinationPrefix": "01",
"validFrom": "0",
"validTo": "inf",
"zoneResult": {
"zoneName": "ic5"
}
}
]
}
],
"attributeSpecMaps": [
{
"name": "TelcoGsmTelephony",
"internalId": "35741bee-6b23-4ef5-b87f-c5b10edf0b5d",
"priceListName": "Default",
"obsolete": false,
"eventRUMSpec": [
{
"name": "EventSession_ERS",
"internalId": "36af81ba-0350-404a-9284-9b31d9910b87",
"priceListName": "Default",
"obsolete": false,
"eventSpecName": "EventSession",
"rumSpec": [
{
"rumExpression": {
"numericRumExpression": {
"value": 1.0
}
},
"rumName": "Volume"
}
]
},
{
"name": "EventDelayedSession_ERS",
"internalId": "9b767286-e804-47d4-815c-b1112e8e7f08",
"priceListName": "Default",
"obsolete": false,
"eventSpecName": "EventDelayedSession",
"rumSpec": [
{
"rumExpression": {
"numericRumExpression": {
"value": 1.0
}
},
"rumName": "Volume"
}
]
},
{
"name": "EventDelayedSessionTelcoGsm_ERS",
"internalId": "91ba61d0-3ad9-4bcf-9b1d-3ab7b49acd3c",
"priceListName": "Default",
"obsolete": false,
"eventSpecName": "EventDelayedSessionTelcoGsm",
"rumSpec": [
{
"rumExpression": {
"numericRumExpression": {
"value": 1.0
}
},
"rumName": "Volume"
},
{
"rumExpression": {
"binaryRUMExpression": {
"leftOperand": {
"eventFieldExpression": {
"fieldName": "EventDelayedSessionTelcoGsm.END_T"
}
},
"rightOperand": {
"eventFieldExpression": {
"fieldName": "EventDelayedSessionTelcoGsm.START_T"
}
},
"operation": "SUBTRACT"
}
},
"rumName": "Duration"
}
]
},
{
"name": "EventBillingProductFeePurchase_ERS",
"internalId": "7935ef42-722e-4853-920d-56fe31b4d313",
"priceListName": "Default",
"obsolete": false,
"eventSpecName": "EventBillingProductFeePurchase",
"rumSpec": [
{
"rumExpression": {
"numericRumExpression": {
"value": 1.0
}
},
"rumName": "Messages"
},
{
"rumExpression": {
"numericRumExpression": {
"value": 1.0
}
},
"rumName": "Occurrence"
}
]
},
{
"name": "EventBillingProductFeeCycleCycle_forward_monthly_ERS",
"internalId": "e807f413-4cf4-4c7b-97ea-58b9c4eaa9c5",
"priceListName": "Default",
"obsolete": false,
"eventSpecName": "EventBillingProductFeeCycleCycle_forward_monthly",
"rumSpec": [
{
"rumExpression": {
"numericRumExpression": {
"value": 1.0
}
},
"rumName": "Occurrence"
}
]
}
],
"productSpecName": "TelcoGsmTelephony"
}
],
"customAnalyzerRules": [
{
"name": "car1",
"description": "car desc",
"internalId": "80cadb2e-0f01-434e-bee3-fec61a4c01fa",
"priceListName": "Default",
"obsolete": false,
"customRuleScopes": [
{
"profileSpecName": "ProfileSubscriber_preferences"
}
],
"customRuleExpression": {
"fieldToValueCRExpression": {
"seperator": ",",
"operator": "EQUAL_TO",
"fieldName": "AnyEvent.AMOUNT",
"fieldKind": "EVENT_SPEC_FIELD",
"fieldValue": "20"
}
}
}
],
"policySpecifications": [
{
"name": "ps1",
"description": "ps1 desc",
"internalId": "3ca7cd41-1561-4334-a7fc-ce2a8abfa24d",
"priceListName": "Default",
"obsolete": false,
"counterPolicies": [
{
"label": "pc1",
"balanceElementNumCode": "100002",
"unit": "HOUR",
"counterRanges": [
{
"lowerBound": "10.0",
"label": "pc1 label"
}
]
}
]
}
],
"policyLabels": [
{
"name": "pc1",
"internalId": "cbf086bc-46c5-4164-9f1a-8994ee07193d",
"priceListName": "Default",
"obsolete": false,
"subLabels": [
{
"subLabel": "pc1 label"
}
]
}
]
}